@@ -360,13 +360,16 @@ void MimeTypeData::syncServices()
     if (!m_bFullInit)
         return;
 
-    KSharedConfig::Ptr profile = KSharedConfig::openConfig("mimeapps.list", KConfig::NoGlobals, QStandardPaths::ApplicationsLocation);
+    KSharedConfig::Ptr profile = KSharedConfig::openConfig("mimeapps.list", KConfig::NoGlobals, QStandardPaths::GenericConfigLocation);
 
     if (!profile->isConfigWritable(true)) // warn user if mimeapps.list is root-owned (#155126/#94504)
         return;
 
     const QStringList oldAppServices = getAppOffers();
     if (oldAppServices != m_appServices) {
+        // Save the default application according to mime-apps-spec 1.0
+        KConfigGroup defaultApp(profile, "Default Applications");
+        saveDefaultApplication(defaultApp, m_appServices);
         // Save preferred services
         KConfigGroup addedApps(profile, "Added Associations");
         saveServices(addedApps, m_appServices);
@@ -432,6 +435,14 @@ void MimeTypeData::saveServices(KConfigGroup & config, const QStringList& servic
         config.writeXdgListEntry(name(), collectStorageIds(services));
 }
 
+void MimeTypeData::saveDefaultApplication(KConfigGroup & config, const QStringList& services)
+{
+    if (services.isEmpty())
+        config.deleteEntry(name());
+    else
+        config.writeXdgListEntry(name(), QStringList(collectStorageIds(services).first()));
+}
+
 void MimeTypeData::refresh()
 {
     if (m_isGroup)
